/**
 * @example
 * ",CAT001,FOO456" => ["CAT001", "FOO456"]
 */
const normalizeActiveGroupIds = (c) => c.trim().split(',').filter(Boolean);
export const getOneTrustGlobal = () => window.OneTrust;
const getOneTrustActiveGroups = () => window.OnetrustActiveGroups;
export const getConsentedGroupIds = () => {
    const groups = getOneTrustActiveGroups();
    if (!groups) {
        return [];
    }
    return normalizeActiveGroupIds(groups || '');
};
const normalizeGroupInfo = (groupInfo) => ({
    groupId: groupInfo.CustomGroupId.trim(),
});
/**
 * get *all* groups / categories, not just active ones
 */
const getAllGroups = () => {
    const oneTrustGlobal = getOneTrustGlobal();
    if (!oneTrustGlobal)
        return [];
    return oneTrustGlobal.GetDomainData().Groups.map(normalizeGroupInfo);
};
// derive the groupIds from the active groups
export const getGroupData = () => {
    const userSetConsentGroupIds = getConsentedGroupIds();
    // partition all groups into "consent" or "deny"
    const userConsentGroupData = getAllGroups().reduce((acc, group) => {
        if (userSetConsentGroupIds.includes(group.groupId)) {
            acc.userSetConsentGroups.push(group);
        }
        else {
            acc.userDeniedConsentGroups.push(group);
        }
        return acc;
    }, { userSetConsentGroups: [], userDeniedConsentGroups: [] });
    return userConsentGroupData;
};
//# sourceMappingURL=onetrust-api.js.map